==> leechcraft-0.3.65.tar.bz2: leechcraft-0.3.65/src/plugins/vgrabber/leechcraft_vgrabber_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>CategoriesSelector</name>
    <message>
        <location filename="categoriesselector.ui" line="33"/>
        <source>Categories</source>
        <translation>Категории</translation>
    </message>
    <message>
        <location filename="categoriesselector.ui" line="43"/>
        <source>Add...</source>
        <translation>Добавить...</translation>
    </message>
    <message>
        <location filename="categoriesselector.ui" line="50"/>
        <source>Modify...</source>
        <translation>Изменить...</translation>
    </message>
    <message>
        <location filename="categoriesselector.ui" line="57"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::vGrabber::AudioFindProxy</name>
    <message>
        <location filename="audiofindproxy.cpp" line="53"/>
        <source>Searching for %1...</source>
        <translation>Поиск %1...</translation>
    </message>
    <message>
        <location filename="audiofindproxy.cpp" line="72"/>
        <source>Audio vkontakte.ru</source>
        <translation>Аудио В Контакте</translation>
    </message>
    <message>
        <location filename="audiofindproxy.cpp" line="225"/>
        <source>Nothing found for %1</source>
        <translation>Ничего не найдено для %1</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::vGrabber::CategoriesSelector</name>
    <message>
        <location filename="categoriesselector.cpp" line="166"/>
        <source>Add category</source>
        <translation>Добавление категории</translation>
    </message>
    <message>
        <location filename="categoriesselector.cpp" line="183"/>
        <source>Modify category</source>
        <translation>Изменение категории</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::vGrabber::FindProxy</name>
    <message>
        <location filename="findproxy.cpp" line="36"/>
        <source>Download</source>
        <translation>Скачать</translation>
    </message>
    <message>
        <location filename="findproxy.cpp" line="43"/>
        <source>Handle</source>
        <translation>Обработать</translation>
    </message>
    <message>
        <location filename="findproxy.cpp" line="60"/>
        <source>Empty search string</source>
        <translation>Пустой запрос</translation>
    </message>
    <message>
        <location filename="findproxy.cpp" line="81"/>
        <source>Job for request&lt;br /&gt;%1&lt;br /&gt;wasn&apos;t delegated.</source>
        <translation>Задача для запроса&lt;br /&gt;%1&lt;br /&gt;не была делегирована.</translation>
    </message>
    <message>
        <location filename="findproxy.cpp" line="140"/>
        <source>Could not open file %1.</source>
        <translation>Невозможно открыть файл %1.</translation>
    </message>
    <message>
        <location filename="findproxy.cpp" line="156"/>
        <source>Search request for URL&lt;br /&gt;%1&lt;br /&gt;was delegated, but it failed.</source>
        <translation>Поисковый запрос для URL&lt;br /&gt;%1&lt;br /&gt;был делегирован, но не удался.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::vGrabber::Plugin</name>
    <message>
        <source>vkontakte.ru music/video grabber.</source>
        <translation type="obsolete">Граббер музыки/видео vkontakte.ru.</translation>
    </message>
    <message>
        <source>LeechCraft</source>
        <translation type="obsolete">LeechCraft</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::vGrabber::VideoFindProxy</name>
    <message>
        <location filename="videofindproxy.cpp" line="34"/>
        <source>Searching for %1...</source>
        <translation>Поиск %1...</translation>
    </message>
    <message>
        <location filename="videofindproxy.cpp" line="53"/>
        <source>Video vkontakte.ru</source>
        <translation>Видео В Контакте</translation>
    </message>
    <message>
        <location filename="videofindproxy.cpp" line="66"/>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <location filename="videofindproxy.cpp" line="183"/>
        <source>Nothing found for %1</source>
        <translation>Ничего не найдено для %1</translation>
    </message>
    <message>
        <location filename="videofindproxy.cpp" line="279"/>
        <source>Job for request&lt;br /&gt;%1&lt;br /&gt;wasn&apos;t delegated.</source>
        <translation>Задача для запроса&lt;br /&gt;%1&lt;br /&gt;не была делегирована.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::vGrabber::vGrabber</name>
    <message>
        <location filename="vgrabber.cpp" line="80"/>
        <source>vkontakte.ru audio/video grabber.</source>
        <translation>Скачивание и проигрывание медиа-файлов В Контакте.</translation>
    </message>
    <message>
        <location filename="vgrabber.cpp" line="163"/>
        <source>LeechCraft</source>
        <translation>LeechCraft</translation>
    </message>
</context>
</TS>

==> leechcraft-0.3.80_rc20101221.tar.bz2: leechcraft-0.3.80_rc20101221/src/plugins/vgrabber/leechcraft_vgrabber_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>CategoriesSelector</name>
    <message>
        <location filename="categoriesselector.ui" line="33"/>
        <source>Categories</source>
        <translation>Категории</translation>
    </message>
    <message>
        <location filename="categoriesselector.ui" line="43"/>
        <source>Add...</source>
        <translation>Добавить...</translation>
    </message>
    <message>
        <location filename="categoriesselector.ui" line="50"/>
        <source>Modify...</source>
        <translation>Изменить...</translation>
    </message>
    <message>
        <location filename="categoriesselector.ui" line="57"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::vGrabber::AudioFindProxy</name>
    <message>
        <location filename="audiofindproxy.cpp" line="53"/>
        <source>Searching for %1...</source>
        <translation>Поиск %1...</translation>
    </message>
    <message>
        <location filename="audiofindproxy.cpp" line="72"/>
        <source>Audio vkontakte.ru</source>
        <translation>Аудио В Контакте</translation>
    </message>
    <message>
        <location filename="audiofindproxy.cpp" line="242"/>
        <source>Nothing found for %1</source>
        <translation>Ничего не найдено для %1</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::vGrabber::CategoriesSelector</name>
    <message>
        <location filename="categoriesselector.cpp" line="166"/>
        <source>Add category</source>
        <translation>Добавление категории</translation>
    </message>
    <message>
        <location filename="categoriesselector.cpp" line="183"/>
        <source>Modify category</source>
        <translation>Изменение категории</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::vGrabber::FindProxy</name>
    <message>
        <location filename="findproxy.cpp" line="41"/>
        <source>Download</source>
        <translation>Скачать</translation>
    </message>
    <message>
        <location filename="findproxy.cpp" line="48"/>
        <source>Handle</source>
        <translation>Обработать</translation>
    </message>
    <message>
        <location filename="findproxy.cpp" line="55"/>
        <source>Copy URL to clipboard</source>
        <translation>Скопировать URL в буфер обмена</translation>
    </message>
    <message>
        <location filename="findproxy.cpp" line="63"/>
        <source>vGrabber menu</source>
        <translation>Меню vGrabber</translation>
    </message>
    <message>
        <location filename="findproxy.cpp" line="80"/>
        <source>Empty search string</source>
        <translation>Пустой запрос</translation>
    </message>
    <message>
        <location filename="findproxy.cpp" line="101"/>
        <source>Job for request&lt;br /&gt;%1&lt;br /&gt;wasn&apos;t delegated.</source>
        <translation>Задача для запроса&lt;br /&gt;%1&lt;br /&gt;не была делегирована.</translation>
    </message>
    <message>
        <location filename="findproxy.cpp" line="181"/>
        <source>Could not open file %1.</source>
        <translation>Невозможно открыть файл %1.</translation>
    </message>
    <message>
        <location filename="findproxy.cpp" line="197"/>
        <source>Search request for URL&lt;br /&gt;%1&lt;br /&gt;was delegated, but it failed.</source>
        <translation>Поисковый запрос для URL&lt;br /&gt;%1&lt;br /&gt;был делегирован, но не удался.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::vGrabber::VideoFindProxy</name>
    <message>
        <location filename="videofindproxy.cpp" line="34"/>
        <source>Searching for %1...</source>
        <translation>Поиск %1...</translation>
    </message>
    <message>
        <location filename="videofindproxy.cpp" line="53"/>
        <source>Video vkontakte.ru</source>
        <translation>Видео В Контакте</translation>
    </message>
    <message>
        <location filename="videofindproxy.cpp" line="66"/>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <location filename="videofindproxy.cpp" line="165"/>
        <source>Nothing found for %1</source>
        <translation>Ничего не найдено для %1</translation>
    </message>
    <message>
        <location filename="videofindproxy.cpp" line="273"/>
        <source>Job for request&lt;br /&gt;%1&lt;br /&gt;wasn&apos;t delegated.</source>
        <translation>Задача для запроса&lt;br /&gt;%1&lt;br /&gt;не была делегирована.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::vGrabber::vGrabber</name>
    <message>
        <location filename="vgrabber.cpp" line="88"/>
        <source>vkontakte.ru audio/video grabber.</source>
        <translation>Скачивание и проигрывание медиа-файлов В Контакте.</translation>
    </message>
</context>
<context>
    <name>vgrabbersettings</name>
    <message>
        <location filename="dummy.cpp" line="2"/>
        <source>General settings</source>
        <translation>Общие настройки</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="3"/>
        <source>Audio</source>
        <translation>Аудио</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="4"/>
        <source>Filter files with the same URL</source>
        <translation>Отфильтровывать файлы с одинаковым адресом</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="5"/>
        <source>Filter files with same title and length</source>
        <translation>Отфильтровывать файлы с одинаковыми именами и длинами</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="6"/>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
</context>
</TS>
